Package: protViz
Type: Package
Title: Visualizing and Analyzing Mass Spectrometry Related Data in
        Proteomics
Version: 0.2.45
Authors@R: c(person("Christian", "Panse", email = "cp@fgcz.ethz.ch", role = c("aut", "cre"), 
        comment = c(ORCID = "0000-0003-1975-3064")),
	person("Jonas", "Grossmann", email = "jg@fgcz.ethz.ch", role = "aut",
	comment = c(ORCID = "0000-0002-6899-9020")),
	person("Simon", "Barkow-Oesterreicher", role = "ctb"))
Author: Christian Panse [aut, cre] (0000-0003-1975-3064),
	Jonas Grossmann [aut] (0000-0002-6899-9020),
	Simon Barkow-Oesterreicher [ctb]
Maintainer: Christian Panse <cp@fgcz.ethz.ch>
Depends: R (>= 3.3), methods
Imports: Rcpp (>= 0.12.8)
LinkingTo: Rcpp
RcppModules: FastaMod
Suggests: lattice, RUnit, xtable
Description: Helps with quality checks, visualizations 
    and analysis of mass spectrometry data, coming from proteomics 
    experiments. The package is developed, tested and used at the Functional 
    Genomics Center Zurich. We use this package mainly for prototyping, 
    teaching, and having fun with proteomics data. But it can also be 
    used to do data analysis for small scale data sets.
License: GPL-3
URL: https://github.com/protViz/protViz/
BugReports: https://github.com/protViz/protViz/issues
Collate: aa2mass.R deisotoper.R de_novo.R findNN.R fragmentIon.R
        genMod.R iTRAQ2GroupAnalysis.R lcmsmap.R mascot.R mdp.R
        parentIonMass.R peakplot.R pgImporter.R pgLFQ.R pp.R psm.R
        PTM_MarkerFinder.R ssrc.R zzz.R RcppExports.R protViz-package.R
Encoding: UTF-8
LazyData: true
NeedsCompilation: yes
Repository: CRAN
SystemRequirements: C++11
Packaged: 2017-11-17 10:17:21 UTC; cp
Date/Publication: 2017-11-17 10:51:48 UTC
Built: R 3.3.2; x86_64-w64-mingw32; 2018-02-04 05:19:38 UTC; windows
Archs: x64
