Package: protViz
Type: Package
Title: Visualizing and Analyzing Mass Spectrometry Related Data in
        Proteomics
Version: 0.7.3
Authors@R: c(person("Christian", "Panse", email = "cp@fgcz.ethz.ch", role = c("aut", "cre"), 
        comment = c(ORCID = "0000-0003-1975-3064")),
	person("Jonas", "Grossmann", email = "jg@fgcz.ethz.ch", role = "aut",
	comment = c(ORCID = "0000-0002-6899-9020")),
	person("Simon", "Barkow-Oesterreicher", role = "ctb"))
Depends: R (>= 4.1), methods
Imports: Rcpp (>= 1.0)
LinkingTo: Rcpp (>= 1.0)
RcppModules: FastaMod
Suggests: lattice, testthat, xtable
Description: Helps with quality checks, visualizations 
    and analysis of mass spectrometry data, coming from proteomics 
    experiments. The package is developed, tested and used at the Functional 
    Genomics Center Zurich <https://fgcz.ch>. We use this package
    mainly for prototyping, teaching, and having fun with proteomics data.
    But it can also be used to do data analysis for small scale data sets.
License: GPL-3
URL: https://github.com/cpanse/protViz/
BugReports: https://github.com/cpanse/protViz/issues
Collate: aa2mass.R centroid.R comet.R deisotoper.R de_novo.R findNN.R
        fragmentIon.R genMod.R iTRAQ2GroupAnalysis.R lcmsmap.R mascot.R
        mdp.R parentIonMass.R peakplot.R pepxml.R pgImporter.R pgLFQ.R
        pp.R psm.R queue.R PTM_MarkerFinder.R ssrc.R zzz.R
        RcppExports.R protViz-package.R
Encoding: UTF-8
LazyData: true
NeedsCompilation: yes
Repository: CRAN
Packaged: 2022-04-04 11:59:17 UTC; cp
Author: Christian Panse [aut, cre] (<https://orcid.org/0000-0003-1975-3064>),
  Jonas Grossmann [aut] (<https://orcid.org/0000-0002-6899-9020>),
  Simon Barkow-Oesterreicher [ctb]
Maintainer: Christian Panse <cp@fgcz.ethz.ch>
Date/Publication: 2022-04-04 13:00:02 UTC
Built: R 4.1.3; x86_64-w64-mingw32; 2022-04-04 16:40:13 UTC; windows
Archs: x64
