export(Fasta)

useDynLib(protViz, .registration = TRUE)
#useDynLib(protViz)

import("methods")
import("Rcpp")

importFrom("stats", "lm")

importFrom("grDevices", "dev.off", "gray.colors", "pdf", "rainbow",
             "rgb")

importFrom("graphics", "abline", "axis", "barplot", "box", "boxplot",
             "close.screen", "hist", "image", "legend", "lines", "par",
             "pie", "plot", "points", "rect", "screen", "segments",
             "split.screen", "text")

importFrom("stats", "aov", "cor", "dist", "dnorm", "quantile",
             "reshape", "sd", "t.test")

importFrom("utils", "combn", "packageVersion", "read.table",
             "write.table", "object.size")


importFrom("stats", "rexp")


export("aa2mass")
export("defaultIon")
export("deisotoper")
export("de_novo")
export("findNN_", "lower_bound_")
export("findNN")
export("fragmentIon")
export("genMod")
export("iTRAQ2GroupAnalysis")
export("lcmsmap")
export("mdp")
export("parentIonMass")
export("peakplot")
export("pgImporter")
export("pgLFQaov")
export("pgLFQtNpq")



export("ppp")
export("pps")
export("psm")
export("PTM_MarkerFinder")
export("PTM_MarkerFinder_util")
export("ssrc")

export("is.psm")
export("plot.psm")
S3method(plot, psm)

S3method(plot, psmSet)
S3method(summary, psmSet)

export("is.psmSet")
export("summary.psmSet")
export("plot.psmSet")
export("as.data.frame.psmSet")
export("findMz")
export("findMz.psmSet")
S3method(findMz, psmSet)
export("as.psmSet")
S3method(as.data.frame, psmSet)


S3method(is, mascot)
S3method(is, mascot_query)
S3method(plot, mascot)
S3method(plot, mascot_query)
S3method(summary, mascot)
S3method(as.data.frame, mascot)
S3method(findMz, mascot)
S3method(as.psmSet, mascot)
export("plot.mascot", "plot.mascot_query", "summary.mascot",
       "as.data.frame.mascot", "is.mascot", "is.mascot_query",
       "findMz.mascot", "as.psm.mascot_query")


#S3method(is, FASTA)
#S3method(as, FASTA)
#S3method(summary, FASTA)

#export("is.FASTA", "as.FASTA", "summary.FASTA", "read.FASTA")
#export("summary.FASTA")
